@@ -33,10 +33,8 @@
 
 namespace vcg{
 
-
-
     // hashing function
-    struct HashFunctor : public std::unary_function<Point3i, size_t>
+    struct HashFunctor
     {
         enum
           { // parameters for hash table
